==> huaweicloudsdkcss-3.1.133-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/update_es_listener_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateEsListenerRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'listener_id': 'str',
        'body': 'UpdateEsListenerRequestBody'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'listener_id': 'listener_id',
        'body': 'body'
    }

    def __init__(self, cluster_id=None, listener_id=None, body=None):
        """UpdateEsListenerRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 指定待操作的集群ID。
        :type cluster_id: str
        :param listener_id: 指定待操作得监听器ID。
        :type listener_id: str
        :param body: Body of the UpdateEsListenerRequest
        :type body: :class:`huaweicloudsdkcss.v1.UpdateEsListenerRequestBody`
        """
        
        

        self._cluster_id = None
        self._listener_id = None
        self._body = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.listener_id = listener_id
        if body is not None:
            self.body = body

    @property
    def cluster_id(self):
        """Gets the cluster_id of this UpdateEsListenerRequest.

        指定待操作的集群ID。

        :return: The cluster_id of this UpdateEsListenerRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this UpdateEsListenerRequest.

        指定待操作的集群ID。

        :param cluster_id: The cluster_id of this UpdateEsListenerRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def listener_id(self):
        """Gets the listener_id of this UpdateEsListenerRequest.

        指定待操作得监听器ID。

        :return: The listener_id of this UpdateEsListenerRequest.
        :rtype: str
        """
        return self._listener_id

    @listener_id.setter
    def listener_id(self, listener_id):
        """Sets the listener_id of this UpdateEsListenerRequest.

        指定待操作得监听器ID。

        :param listener_id: The listener_id of this UpdateEsListenerRequest.
        :type listener_id: str
        """
        self._listener_id = listener_id

    @property
    def body(self):
        """Gets the body of this UpdateEsListenerRequest.

        :return: The body of this UpdateEsListenerRequest.
        :rtype: :class:`huaweicloudsdkcss.v1.UpdateEsListenerRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateEsListenerRequest.

        :param body: The body of this UpdateEsListenerRequest.
        :type body: :class:`huaweicloudsdkcss.v1.UpdateEsListenerRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEsListenerRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcss-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/update_es_listener_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateEsListenerRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'listener_id': 'str',
        'body': 'UpdateEsListenerRequestBody'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'listener_id': 'listener_id',
        'body': 'body'
    }

    def __init__(self, cluster_id=None, listener_id=None, body=None):
        r"""UpdateEsListenerRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 指定待操作的集群ID。
        :type cluster_id: str
        :param listener_id: 指定待操作得监听器ID。
        :type listener_id: str
        :param body: Body of the UpdateEsListenerRequest
        :type body: :class:`huaweicloudsdkcss.v1.UpdateEsListenerRequestBody`
        """
        
        

        self._cluster_id = None
        self._listener_id = None
        self._body = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.listener_id = listener_id
        if body is not None:
            self.body = body

    @property
    def cluster_id(self):
        r"""Gets the cluster_id of this UpdateEsListenerRequest.

        指定待操作的集群ID。

        :return: The cluster_id of this UpdateEsListenerRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        r"""Sets the cluster_id of this UpdateEsListenerRequest.

        指定待操作的集群ID。

        :param cluster_id: The cluster_id of this UpdateEsListenerRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def listener_id(self):
        r"""Gets the listener_id of this UpdateEsListenerRequest.

        指定待操作得监听器ID。

        :return: The listener_id of this UpdateEsListenerRequest.
        :rtype: str
        """
        return self._listener_id

    @listener_id.setter
    def listener_id(self, listener_id):
        r"""Sets the listener_id of this UpdateEsListenerRequest.

        指定待操作得监听器ID。

        :param listener_id: The listener_id of this UpdateEsListenerRequest.
        :type listener_id: str
        """
        self._listener_id = listener_id

    @property
    def body(self):
        r"""Gets the body of this UpdateEsListenerRequest.

        :return: The body of this UpdateEsListenerRequest.
        :rtype: :class:`huaweicloudsdkcss.v1.UpdateEsListenerRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateEsListenerRequest.

        :param body: The body of this UpdateEsListenerRequest.
        :type body: :class:`huaweicloudsdkcss.v1.UpdateEsListenerRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEsListenerRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
